@@ -10,7 +10,7 @@
 //! Add [**Interoptopus**](https://crates.io/crates/interoptopus) attributes to the library you have
 //! written, and define an [**inventory**](https://docs.rs/interoptopus/latest/interoptopus/macro.inventory.html)
 //! function listing all symbols you wish to export. An overview of all supported constructs can be found in the
-//! [**reference project**](https://github.com/ralfbiedert/interoptopus/tree/master/interoptopus_reference_project/src).
+//! [**reference project**](https://github.com/ralfbiedert/interoptopus/tree/master/reference_project/src).
 //!
 //! ```rust
 //! use interoptopus::{ffi_function, ffi_type};
@@ -47,22 +47,25 @@
 //! Create a unit test in `tests/bindings.rs` which will generate your bindings when run
 //! with `cargo test`. In real projects you might want to add this code to another crate instead:
 //!
-//! ```
+//!```
 //! use interoptopus::util::NamespaceMappings;
 //! use interoptopus::{Error, Interop};
 //!
 //! #[test]
 //! fn bindings_csharp() -> Result<(), Error> {
 //!     use interoptopus_backend_csharp::{Config, Generator};
+//!     use interoptopus_backend_csharp::overloads::{DotNet, Unity};
 //!
-//!     Generator::new(
-//!         Config {
-//!             dll_name: "example_library".to_string(),
-//!             namespace_mappings: NamespaceMappings::new("My.Company"),
-//!             ..Config::default()
-//!         },
-//!         example_library_ffi::my_inventory(),
-//!     ).write_file("bindings/csharp/Interop.cs")?;
+//!     let config = Config {
+//!         dll_name: "example_library".to_string(),
+//!         namespace_mappings: NamespaceMappings::new("My.Company"),
+//!         ..Config::default()
+//!     };
+//!
+//!     Generator::new(config, example_library_ffi::my_inventory())
+//!         .add_overload_writer(DotNet::new())
+//!         //.add_overload_writer(Unity::new())
+//!         .write_file("bindings/csharp/Interop.cs")?;
 //!
 //!     Ok(())
 //! }
@@ -110,9 +113,11 @@
 use interoptopus::writer::IndentWriter;
 use interoptopus::Interop;
 use interoptopus::{Error, Library};
+use overloads::OverloadWriter;
 
 mod config;
 mod converter;
+pub mod overloads;
 mod testing;
 mod writer;
 
@@ -126,6 +131,7 @@ pub struct Generator {
     config: Config,
     library: Library,
     converter: Converter,
+    overload_writer: Vec<Box<dyn OverloadWriter>>,
 }
 
 impl Generator {
@@ -134,8 +140,14 @@ impl Generator {
             config,
             library,
             converter: Converter {},
+            overload_writer: vec![],
         }
     }
+
+    pub fn add_overload_writer(&mut self, writer: Box<dyn OverloadWriter>) -> &mut Self {
+        self.overload_writer.push(writer);
+        self
+    }
 }
 
 impl Interop for Generator {
@@ -156,4 +168,8 @@ impl CSharpWriter for Generator {
     fn converter(&self) -> &Converter {
         &self.converter
     }
+
+    fn overloads(&self) -> &[Box<dyn OverloadWriter>] {
+        self.overload_writer.as_slice()
+    }
 }
