@@ -916,7 +916,7 @@ pub trait CSharpWriter {
                 indented!(w, [_], r#"var rval = {};"#, fn_call)?;
                 indented!(w, [_], r#"if (rval != {}.{})"#, e.the_enum().rust_name(), e.success_variant().name())?;
                 indented!(w, [_], r#"{{"#)?;
-                indented!(w, [_ _], r#"throw new InteropException(rval);"#)?;
+                indented!(w, [_ _], r#"throw new InteropException<{}>(rval);"#, e.the_enum().rust_name())?;
                 indented!(w, [_], r#"}}"#)?;
             }
             CType::Primitive(PrimitiveType::Void) => {
@@ -937,16 +937,18 @@ pub trait CSharpWriter {
     }
 
     fn write_builtins(&self, w: &mut IndentWriter) -> Result<(), Error> {
-        indented!(w, r#"public class InteropException : Exception"#)?;
-        indented!(w, r#"{{"#)?;
-        indented!(w, [_], r#"public FFIError Error {{ get; private set; }}"#)?;
-        w.newline()?;
-        indented!(w, [_], r#"public InteropException(FFIError error): base($"Something went wrong: {{error}}")"#)?;
-        indented!(w, [_], r#"{{"#)?;
-        indented!(w, [_ _], r#"Error = error;"#)?;
-        indented!(w, [_], r#"}}"#)?;
-        indented!(w, r#"}}"#)?;
-        w.newline()?;
+        if self.config().write_types.write_interoptopus_globals() {
+            indented!(w, r#"public class InteropException<T> : Exception"#)?;
+            indented!(w, r#"{{"#)?;
+            indented!(w, [_], r#"public T Error {{ get; private set; }}"#)?;
+            w.newline()?;
+            indented!(w, [_], r#"public InteropException(T error): base($"Something went wrong: {{error}}")"#)?;
+            indented!(w, [_], r#"{{"#)?;
+            indented!(w, [_ _], r#"Error = error;"#)?;
+            indented!(w, [_], r#"}}"#)?;
+            indented!(w, r#"}}"#)?;
+            w.newline()?;
+        }
 
         Ok(())
     }
