@@ -2,6 +2,7 @@ use interoptopus::testing::assert_file_matches_generated;
 use interoptopus::util::NamespaceMappings;
 use interoptopus::Error;
 use interoptopus::Interop;
+use interoptopus_backend_csharp::overloads::{DotNet, Unity};
 use interoptopus_backend_csharp::{run_dotnet_command_if_installed, Unsafe, WriteTypes};
 
 fn generate_bindings_multi(prefix: &str, use_unsafe: Unsafe) -> Result<(), Error> {
@@ -35,7 +36,15 @@ fn generate_bindings_multi(prefix: &str, use_unsafe: Unsafe) -> Result<(), Error
             ..config.clone()
         };
 
-        Generator::new(config.clone(), interoptopus_reference_project::ffi_inventory()).write_file(file_name)?;
+        let mut generator = Generator::new(config.clone(), interoptopus_reference_project::ffi_inventory());
+
+        generator.add_overload_writer(DotNet::new());
+
+        if use_unsafe.any_unsafe() {
+            generator.add_overload_writer(Unity::new());
+        }
+
+        generator.write_file(file_name)?;
     }
 
     Ok(())
@@ -46,6 +55,7 @@ fn generate_bindings_multi(prefix: &str, use_unsafe: Unsafe) -> Result<(), Error
 fn bindings_match_reference() -> Result<(), Error> {
     generate_bindings_multi("tests/output_safe/Interop", Unsafe::None)?;
     generate_bindings_multi("tests/output_unsafe/Interop", Unsafe::UnsafePlatformMemCpy)?;
+    generate_bindings_multi("tests/output_unity/Assets/Interop", Unsafe::UnsafePlatformMemCpy)?;
 
     assert_file_matches_generated("tests/output_safe/Interop.cs");
     assert_file_matches_generated("tests/output_safe/Interop.common.cs");
@@ -53,6 +63,9 @@ fn bindings_match_reference() -> Result<(), Error> {
     assert_file_matches_generated("tests/output_unsafe/Interop.cs");
     assert_file_matches_generated("tests/output_unsafe/Interop.common.cs");
 
+    assert_file_matches_generated("tests/output_unity/Assets/Interop.cs");
+    assert_file_matches_generated("tests/output_unity/Assets/Interop.common.cs");
+
     Ok(())
 }
 
